@@ -7,8 +7,8 @@ use NBI::Job;
 use NBI::Opts;
 use base qw(Exporter);
 our @ISA = qw(Exporter);
-our @EXPORT = qw(Job Opts %FORMAT_STRINGS);
-$NBI::Slurm::VERSION = '0.4.4';
+our @EXPORT = qw(Job Opts load_config %FORMAT_STRINGS);
+$NBI::Slurm::VERSION = '0.4.11';
 
 
 
@@ -32,9 +32,94 @@ our %FORMAT_STRINGS = (
 );
 
 
+sub load_config {
+    my $filename = shift;
+    if (! $filename) {
+        $filename = "$ENV{HOME}/.nbislurm.config";
+    }
+    my $config = {};
+    if (! -e "$filename") {
+        say STDERR "# Config file not found: $filename" if ($ENV{"DEBUG"});
+        return $config;
+    }
+    open(my $fh, "<", $filename) or die "Cannot open $filename: $!";
+    while (<$fh>) {
+        chomp;
+        next if (/^\s*$/);
+        next if (/^#/);
+        next if (/^;/);
+        my ($key, $value) = split(/=/, $_);
+        # discard keys with spaces
+        next if ($key =~ /\s/);
+        $config->{$key} = $value;
+    }
+    close  $fh;
+    return $config;
+}
 
 
+sub has_squeue {
+    my $cmd = "squeue --version";
+    my $output = `$cmd 2>&1`;
+    if ($? == 0) {
+        return 1;
+    } else {
+        return 0;
+    }
+}
 
+sub queues {
+  my $can_fail = shift;
+  # Retrieve queues from SLURM
+  my $cmd = "sinfo --format '%P' --noheader";
+  my @output = `$cmd 2>/dev/null`;
+  if ($? != 0 and ! $can_fail) {
+    Carp::croak "ERROR NBI::Slurm: sinfo failed. Are you in a SLURM cluster?\n";
+  }
+  chomp @output;
+  return @output;
+}
+
+sub valid_queue {
+  my $queue = shift;
+  my @queues = queues(1);
+  my @input_queues = split(/,/, $queue);
+  foreach my $input_queue (@input_queues) {
+    if (! grep { $_ eq $input_queue } @queues) {
+      return 0;
+    }
+  }
+  return 1;
+}
+
+
+sub days_since_update {
+    my $file_path = shift;
+
+    # Check if the required modules can be loaded
+    eval {
+        require File::Spec;
+        require Time::Piece;
+        require Time::Seconds;
+    };
+    if ($@) {
+        return -1;  # Failed to load required module(s)
+    }
+
+    # Check if the file exists
+    unless (-e $file_path) {
+        return -1;  # File not found
+    }
+
+    # Get the file's last modification time
+    my $last_modified = (stat($file_path))[9];
+
+    # Calculate the number of days since the last modification
+    my $current_time = time();
+    my $days_since_update = int(($current_time - $last_modified) / (24 * 60 * 60));
+
+    return $days_since_update;
+}
 1;
 
 __END__
@@ -49,7 +134,7 @@ NBI::Slurm - NBI Slurm module
 
 =head1 VERSION
 
-version 0.4.4
+version 0.4.11
 
 =head1 SYNOPSIS
 
@@ -111,6 +196,32 @@ One popular scheduler used in HPC environments is B<SLURM> (Simple Linux Utility
 
 SLURM's design philosophy focuses on scalability, fault-tolerance, and extensibility, making it a popular choice for many research institutions and supercomputing centers.
 
+=head1 METHODS
+
+=over 4
+
+=item * B<load_config>
+
+Load configuration from a file.
+
+=item * B<has_squeue>
+
+Check if the squeue command is available.
+
+=item * B<queues>
+
+Retrieve queues from SLURM.
+
+=item * B<valid_queue>
+
+Check if a queue is valid.
+
+=item * B<days_since_update>
+
+Calculate the number of days since a file was last modified.
+
+=back
+
 =head1 CLASSES
 
 The C<NBI::Slurm> package includes the following classes:
